@@ -65,6 +65,8 @@ def cleanup_unpack():
     if TMP_DIR is not None and os.path.isdir(TMP_DIR):
         recursive_rm(TMP_DIR)
         TMP_DIR = None
+
+
 atexit.register(cleanup_unpack)
 
 
@@ -86,7 +88,6 @@ class Review(object):
         'application/x-executable; charset=binary',
         'application/x-sharedlib; charset=binary',
         'application/x-object; charset=binary',
-        'application/octet-stream; charset=binary'
     ]
 
     def __init__(self, fn, review_type, overrides=None):
@@ -96,10 +97,12 @@ class Review(object):
         self.review_type = review_type
         # TODO: rename as pkg_report
         self.click_report = dict()
+        self.stage_report = dict()
 
         self.result_types = ['info', 'warn', 'error']
         for r in self.result_types:
             self.click_report[r] = dict()
+            self.stage_report[r] = dict()
 
         self.click_report_output = "json"
 
@@ -210,9 +213,16 @@ class Review(object):
     def _list_all_compiled_binaries(self):
         '''List all compiled binaries in this click package.'''
         for i in self.pkg_files:
-            res = self.mime.file(i)
+            try:
+                res = self.mime.file(i)
+            except Exception:  # pragma: nocover
+                # workaround for zesty python3-magic
+                debug("could not detemine mime type of '%s'" % i)
+                continue
+
             if res in self.magic_binary_file_descriptions and \
-               not self._check_if_message_catalog(i):
+               not self._check_if_message_catalog(i) and \
+               i not in self.pkg_bin_files:
                 self.pkg_bin_files.append(i)
 
     def _get_check_name(self, name, app='', extra=''):
@@ -234,91 +244,6 @@ class Review(object):
             return True
         return False
 
-    def _get_policy_versions(self, vendor):
-        '''Get the supported AppArmor policy versions'''
-        if not self.aa_policy:
-            return None
-
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return None
-
-        supported_policy_versions = []
-        for i in self.aa_policy[vendor].keys():
-            supported_policy_versions.append("%.1f" % float(i))
-
-        return sorted(supported_policy_versions)
-
-    def _get_templates(self, vendor, version, aa_type="all"):
-        '''Get templates by type'''
-        if not self.aa_policy:
-            return None
-
-        templates = []
-        if aa_type == "all":
-            for k in self.aa_policy[vendor][version]['templates'].keys():
-                templates += self.aa_policy[vendor][version]['templates'][k]
-        else:
-            templates = self.aa_policy[vendor][version]['templates'][aa_type]
-
-        return sorted(templates)
-
-    def _has_policy_version(self, vendor, version):
-        '''Determine if has specified policy version'''
-        if not self.aa_policy:
-            return None
-
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return False
-
-        if str(version) not in self.aa_policy[vendor]:
-            return False
-        return True
-
-    def _get_policy_groups(self, vendor, version, aa_type="all"):
-        '''Get policy groups by type'''
-        if not self.aa_policy:
-            return None
-
-        groups = []
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return groups
-
-        if not self._has_policy_version(vendor, version):
-            error("Could not find version '%s'" % version, do_exit=False)
-            return groups
-
-        v = str(version)
-        if aa_type == "all":
-            for k in self.aa_policy[vendor][v]['policy_groups'].keys():
-                groups += self.aa_policy[vendor][v]['policy_groups'][k]
-        else:
-            groups = self.aa_policy[vendor][v]['policy_groups'][aa_type]
-
-        return sorted(groups)
-
-    def _get_policy_group_type(self, vendor, version, policy_group):
-        '''Return policy group type'''
-        if not self.aa_policy:
-            return None
-
-        for t in self.aa_policy[vendor][version]['policy_groups']:
-            if policy_group in self.aa_policy[vendor][version]['policy_groups'][t]:
-                return t
-        return None
-
-    def _get_template_type(self, vendor, version, template):
-        '''Return template type'''
-        if not self.aa_policy:
-            return None
-
-        for t in self.aa_policy[vendor][version]['templates']:
-            if template in self.aa_policy[vendor][version]['templates'][t]:
-                return t
-        return None
-
     # click_report[<result_type>][<review_name>] = <result>
     #   result_type: info, warn, error
     #   review_name: name of the check (prefixed with self.review_type)
@@ -328,8 +253,14 @@ class Review(object):
     #   override_result_type: prefix results with [<result_type>] and set
     #     result_type to override_result_type
     def _add_result(self, result_type, review_name, result, link=None,
-                    manual_review=False, override_result_type=None):
+                    manual_review=False, override_result_type=None,
+                    stage=False):
         '''Add result to report'''
+        if stage:
+            report = self.stage_report
+        else:
+            report = self.click_report
+
         if result_type not in self.result_types:
             error("Invalid result type '%s'" % result_type)
 
@@ -341,7 +272,7 @@ class Review(object):
             prefix = "[%s] " % result_type.upper()
             result_type = override_result_type
 
-        if review_name not in self.click_report[result_type]:
+        if review_name not in report[result_type]:
             # log info about check so it can be collected into the
             # check-names.list file
             # format should be
@@ -350,14 +281,29 @@ class Review(object):
             name = ':'.join(review_name.split(':')[:2])
             link_text = link if link is not None else ""
             logging.debug(msg.format(name, link_text))
-            self.click_report[result_type][review_name] = dict()
+            report[result_type][review_name] = dict()
 
-        self.click_report[result_type][review_name].update({
+        report[result_type][review_name].update({
             'text': "%s%s" % (prefix, result),
             'manual_review': manual_review,
         })
         if link is not None:
-            self.click_report[result_type][review_name]["link"] = link
+            report[result_type][review_name]["link"] = link
+
+    def _apply_staged_results(self):
+        '''Merge the staged report into the main report'''
+        for result_type in self.stage_report:
+            if result_type not in self.result_types:
+                error("Invalid result type '%s'" % result_type)
+
+            for review_name in self.stage_report[result_type]:
+                if review_name not in self.click_report[result_type]:
+                    self.click_report[result_type][review_name] = dict()
+                for key in self.stage_report[result_type][review_name]:
+                    self.click_report[result_type][review_name][key] = \
+                        self.stage_report[result_type][review_name][key]
+            # reset the staged report
+            self.stage_report[result_type] = dict()
 
     def do_report(self):
         '''Print report'''
@@ -582,7 +528,16 @@ def open_file_read(path):
 
 def recursive_rm(dirPath, contents_only=False):
     '''recursively remove directory'''
-    names = os.listdir(dirPath)
+    try:
+        names = os.listdir(dirPath)
+    except PermissionError:
+        # If directory has weird permissions (eg, 000), just try to remove the
+        # directory if we can. If it is non-empty, we'll legitimately fail
+        # here. This allows us to remove empty directories with weird
+        # permissions.
+        os.rmdir(dirPath)
+        return
+
     for name in names:
         path = os.path.join(dirPath, name)
         if os.path.islink(path) or not os.path.isdir(path):
@@ -649,7 +604,7 @@ def detect_package(fn, dir=None):
     return (pkgtype, pkgver)
 
 
-def find_external_symlinks(unpack_dir, pkg_files):
+def find_external_symlinks(unpack_dir, pkg_files, pkgname):
     '''Check if symlinks in the package go out to the system.'''
     common = '(-[0-9.]+)?\.so(\.[0-9.]+)?'
     libc6_libs = ['ld-*.so',
@@ -689,11 +644,18 @@ def find_external_symlinks(unpack_dir, pkg_files):
                 return True
         return False
 
-    external_symlinks = list(filter(lambda link: not
-                             os.path.realpath(link).startswith(
-                                 unpack_dir) and
-                             not _in_patterns(libc6_pats,
-                                              os.path.basename(link)),
+    def _is_external(link, pats, pkgname):
+        rp = os.path.realpath(link)
+        if not rp.startswith(unpack_dir + "/") and \
+                not rp.startswith(os.path.join("/snap", pkgname) + "/") and \
+                not rp.startswith(
+                    os.path.join("/var/snap", pkgname) + "/") and \
+                not _in_patterns(pats, os.path.basename(link)):
+            return True
+        return False
+
+    external_symlinks = list(filter(lambda link:
+                             _is_external(link, libc6_pats, pkgname),
                              pkg_files))
 
     return [os.path.relpath(i, unpack_dir) for i in external_symlinks]
