@@ -92,12 +92,6 @@ class ClickReview(Review):
                            "security-template",
                            "security-override",
                            "security-policy"]
-    magic_binary_file_descriptions = [
-        'application/x-executable; charset=binary',
-        'application/x-sharedlib; charset=binary',
-        'application/x-object; charset=binary',
-        'application/octet-stream; charset=binary'
-    ]
 
     def __init__(self, fn, review_type, peer_hooks=None, overrides=None,
                  peer_hooks_link=None):
@@ -391,6 +385,90 @@ class ClickReview(Review):
                 d[name][key] = entry[key]
         return d
 
+    def _get_policy_versions(self, vendor):
+        '''Get the supported AppArmor policy versions'''
+        if not self.aa_policy:
+            return None
+
+        if vendor not in self.aa_policy:
+            error("Could not find vendor '%s'" % vendor, do_exit=False)
+            return None
+
+        supported_policy_versions = []
+        for i in self.aa_policy[vendor].keys():
+            supported_policy_versions.append("%.1f" % float(i))
+
+        return sorted(supported_policy_versions)
+
+    def _get_templates(self, vendor, version, aa_type="all"):
+        '''Get templates by type'''
+        if not self.aa_policy:
+            return None
+
+        templates = []
+        if aa_type == "all":
+            for k in self.aa_policy[vendor][version]['templates'].keys():
+                templates += self.aa_policy[vendor][version]['templates'][k]
+        else:
+            templates = self.aa_policy[vendor][version]['templates'][aa_type]
+
+        return sorted(templates)
+
+    def _has_policy_version(self, vendor, version):
+        '''Determine if has specified policy version'''
+        if not self.aa_policy:
+            return None
+
+        if vendor not in self.aa_policy:
+            error("Could not find vendor '%s'" % vendor, do_exit=False)
+            return False
+
+        if str(version) not in self.aa_policy[vendor]:
+            return False
+        return True
+
+    def _get_policy_groups(self, vendor, version, aa_type="all"):
+        '''Get policy groups by type'''
+        if not self.aa_policy:
+            return None
+
+        groups = []
+        if vendor not in self.aa_policy:
+            error("Could not find vendor '%s'" % vendor, do_exit=False)
+            return groups
+
+        if not self._has_policy_version(vendor, version):
+            error("Could not find version '%s'" % version, do_exit=False)
+            return groups
+
+        v = str(version)
+        if aa_type == "all":
+            for k in self.aa_policy[vendor][v]['policy_groups'].keys():
+                groups += self.aa_policy[vendor][v]['policy_groups'][k]
+        else:
+            groups = self.aa_policy[vendor][v]['policy_groups'][aa_type]
+
+        return sorted(groups)
+
+    def _get_policy_group_type(self, vendor, version, policy_group):
+        '''Return policy group type'''
+        if not self.aa_policy:
+            return None
+
+        for t in self.aa_policy[vendor][version]['policy_groups']:
+            if policy_group in self.aa_policy[vendor][version]['policy_groups'][t]:
+                return t
+        return None
+
+    def _get_template_type(self, vendor, version, template):
+        '''Return template type'''
+        if not self.aa_policy:
+            return None
+
+        for t in self.aa_policy[vendor][version]['templates']:
+            if template in self.aa_policy[vendor][version]['templates'][t]:
+                return t
+
     def check_peer_hooks(self, hooks_sublist=[]):
         '''Check if peer hooks are valid'''
         # Nothing to verify
