@@ -27,7 +27,7 @@ from clickreviews.common import (
     open_file_read,
 )
 
-import clickreviews.apparmor_policy as apparmor_policy
+import clickreviews.snapd_base_declaration as snapd_base_declaration
 
 
 #
@@ -44,13 +44,17 @@ class SnapReview(Review):
                        ]
     # optional snappy fields here (may be required by appstore)
     snappy_optional = ['apps',
+                       'assumes',
                        'architectures',
                        'confinement',
                        'description',
                        'environment',
                        'epoch',
-                       'license-agreement',
-                       'license-version',
+                       'grade',
+                       'hooks',
+                       'icon',
+                       'license-agreement',  # OBSOLETE (LP: #1638303)
+                       'license-version',    # OBSOLETE
                        'summary',
                        'type',
                        'plugs',
@@ -58,7 +62,8 @@ class SnapReview(Review):
                        ]
 
     apps_required = ['command']
-    apps_optional = ['daemon',
+    apps_optional = ['aliases',
+                     'daemon',
                      'environment',
                      'stop-command',
                      'stop-timeout',
@@ -72,6 +77,21 @@ class SnapReview(Review):
                      'socket-user',
                      'socket-group',
                      ]
+    hooks_required = []
+    hooks_optional = ['plugs']
+
+    # Valid values for 'type' in packaging yaml
+    # - app
+    # - core
+    # - kernel
+    # - gadget
+    # - os (deprecated)
+    valid_snap_types = ['app',
+                        'core',
+                        'kernel',
+                        'gadget',
+                        'os',
+                        ]
 
     # https://docs.google.com/document/d/1Q5_T00yTq0wobm_nHzCV-KV8R4jdk-PXcrtm80ETTLU/edit#
     # 'plugs':
@@ -85,8 +105,8 @@ class SnapReview(Review):
     # etc).  # Interfaces with no attributes should specify an empty
     # dictionary.
     #
-    # Interfaces from apparmor-easyprof-ubuntu.json are read in __init__() so
-    # they don't have to be added to self.interfaces.
+    # Interfaces are read from the base declaration in __init__() so they don't
+    # have to be added to self.interfaces.
     interfaces = dict()
 
     # Since apparmor-easyprof-ubuntu.json doesn't allow specifying attributes,
@@ -97,11 +117,42 @@ class SnapReview(Review):
                           'content': {'read/slots': [],
                                       'write/slots': [],
                                       'target/plugs': "",
+                                      'default-provider/plugs': "",
+                                      'content/plugs': "",
+                                      'content/slots': "",
                                       },
+                          'dbus': {'name/slots': "",
+                                   'bus/slots': "",
+                                   'name/plugs': "",
+                                   'bus/plugs': "",
+                                   },
+                          'docker-support': {'privileged-containers/plugs':
+                                             False},
                           'gpio': {'number/slots': 0},
-                          'serial-port': {'path/slots': ""},
+                          'hidraw': {'path/slots': "",
+                                     'usb-vendor/slots': 0,
+                                     'usb-product/slots': 0,
+                                     },
+                          'i2c': {'path/slots': ""},
+                          'iio': {'path/slots': ""},
+                          'mpris': {'name/slots': ""},
+                          'serial-port': {'path/slots': "",
+                                          'usb-vendor/slots': 0,
+                                          'usb-product/slots': 0,
+                                          },
                           }
 
+    # In progress interfaces are those that are not yet in snapd but for
+    # some reason we need them. Normally we will never want to do this, but
+    # for example the unity8 interface wass in progress and they wanted CI
+    # uploads
+    inprogress_interfaces = {
+        '16': {
+            'plugs': {},
+            'slots': {},
+        }
+    }
+
     def __init__(self, fn, review_type, overrides=None):
         Review.__init__(self, fn, review_type, overrides=overrides)
 
@@ -119,27 +170,41 @@ class SnapReview(Review):
         # tree, use it unconditionally.
         local_copy = None
         branch_fn = os.path.join(os.path.dirname(__file__),
-                                 '../data/apparmor-easyprof-ubuntu.json')
+                                 '../data/snapd-base-declaration.yaml')
         if os.path.exists(branch_fn):
             local_copy = branch_fn
-        p = apparmor_policy.ApparmorPolicy(local_copy)
-        self.aa_policy = p.policy
+        p = snapd_base_declaration.SnapdBaseDeclaration(local_copy)
+        # FIXME: don't hardcode series
+        self.base_declaration_series = "16"
+        self.base_declaration = p.decl[self.base_declaration_series]
 
-        # TODO: may need updating for ubuntu-personal, etc
-        self.policy_vendor = "ubuntu-core"
-        self.policy_version = str(self._pkgfmt_version())
-
-        if self.policy_vendor in self.aa_policy and \
-                self.policy_version in self.aa_policy[self.policy_vendor] and \
-                'policy_groups' in self.aa_policy[self.policy_vendor][self.policy_version]:
-            for t in ['common', 'reserved']:
-                if t not in self.aa_policy[self.policy_vendor][self.policy_version]['policy_groups']:
+        # Add in-progress interfaces
+        if self.base_declaration_series in self.inprogress_interfaces:
+            rel = self.base_declaration_series
+            for side in ['plugs', 'slots']:
+                if side not in self.base_declaration or \
+                        side not in self.inprogress_interfaces[rel]:
                     continue
-                for p in self.aa_policy[self.policy_vendor][self.policy_version]['policy_groups'][t]:
-                    if p in self.interfaces_attribs:
-                        self.interfaces[p] = self.interfaces_attribs[p]
-                    else:
-                        self.interfaces[p] = {}
+
+                if side == 'plugs':
+                    oside = 'slots'
+                else:
+                    oside = 'plugs'
+
+                for iface in self.inprogress_interfaces[rel][side]:
+                    if iface in self.base_declaration[side] or \
+                            iface in self.base_declaration[oside]:
+                        # don't override anything in the base declaration
+                        continue
+                    self.base_declaration[side][iface] = self.inprogress_interfaces[rel][side][iface]
+
+        # to simplify checks, gather up all the interfaces into one dict()
+        for side in ['plugs', 'slots']:
+            for k in self.base_declaration[side]:
+                if k in self.interfaces_attribs:
+                    self.interfaces[k] = self.interfaces_attribs[k]
+                else:
+                    self.interfaces[k] = {}
 
         # default to 'app'
         if 'type' not in self.snap_yaml:
@@ -183,9 +248,14 @@ class SnapReview(Review):
 
     def _verify_pkgname(self, n):
         '''Verify package name'''
-        pat = re.compile(r'^[a-z](?:-?[a-z0-9])*$')
+        # From validSnapName in snapd/snap/validate.go:
+        #   "^(?:[a-z0-9]+-?)*[a-z](?:-?[a-z0-9])*$"
+        # but this regex is very inefficient and certain names will make python
+        # work extremely hard. Instead we use this and make sure the name isn't
+        # all digits.
+        pat = re.compile(r'^[a-z0-9](?:-?[a-z0-9])*$')
 
-        if pat.search(n):
+        if pat.search(n) and not n.isnumeric():
             return True
         return False
 
@@ -196,10 +266,3 @@ class SnapReview(Review):
         if pat.search(n):
             return True
         return False
-
-    def _devmode_override(self):
-        '''Determine override result type based on confinement property'''
-        if 'confinement' in self.snap_yaml and \
-                self.snap_yaml['confinement'] == "devmode":
-            return 'info'
-        return None
