@@ -43,12 +43,9 @@ class SnapReviewSecurity(SnapReview):
                                   'os',
                                   'kernel']  # these don't need security items
 
-        self.sec_safe_slots = ['content',
-                               'mpris']
-
         # Let's try to catch weird stuff in the os snap
         self.sec_mode_overrides = {
-            'ubuntu-core': {
+            'core': {
                 './bin/mount': 'rwsr-xr-x',
                 './bin/ping': 'rwsr-xr-x',
                 './bin/ping6': 'rwsr-xr-x',
@@ -89,120 +86,56 @@ class SnapReviewSecurity(SnapReview):
             'chrome-test': {  # chrome-test from Canonical
                 './opt/google/chrome/chrome-sandbox': 'rwsr-xr-x',
             },
+            'openwrt': {  # demo from Canonical
+                './rootfs/tmp': 'rwxrwxrwt',
+            },
+            'ubuntu-core': {
+                './bin/mount': 'rwsr-xr-x',
+                './bin/ping': 'rwsr-xr-x',
+                './bin/ping6': 'rwsr-xr-x',
+                './bin/su': 'rwsr-xr-x',
+                './bin/umount': 'rwsr-xr-x',
+                './etc/chatscripts': 'rwxr-s---',
+                './etc/ppp/peers': 'rwxr-s---',
+                './run/lock': 'rwxrwxrwt',
+                './sbin/pam_extrausers_chkpwd': 'rwxr-sr-x',
+                './sbin/unix_chkpwd': 'rwxr-sr-x',
+                './tmp': 'rwxrwxrwt',
+                './usr/bin/chage': 'rwxr-sr-x',
+                './usr/bin/chfn': 'rwsr-xr-x',
+                './usr/bin/chsh': 'rwsr-xr-x',
+                './usr/bin/crontab': 'rwxr-sr-x',
+                './usr/bin/dotlockfile': 'rwxr-sr-x',
+                './usr/bin/expiry': 'rwxr-sr-x',
+                './usr/bin/gpasswd': 'rwsr-xr-x',
+                './usr/bin/mail-lock': 'rwxr-sr-x',
+                './usr/bin/mail-unlock': 'rwxr-sr-x',
+                './usr/bin/mail-touchlock': 'rwxr-sr-x',
+                './usr/bin/newgrp': 'rwsr-xr-x',
+                './usr/bin/passwd': 'rwsr-xr-x',
+                './usr/bin/ssh-agent': 'rwxr-sr-x',
+                './usr/bin/sudo': 'rwsr-xr-x',
+                './usr/bin/wall': 'rwxr-sr-x',
+                './usr/lib/dbus-1.0/dbus-daemon-launch-helper': 'rwsr-xr--',
+                './usr/lib/openssh/ssh-keysign': 'rwsr-xr-x',
+                './usr/lib/snapd/snap-confine': 'rwsr-xr-x',
+                './usr/local/lib/python3.5': 'rwxrwsr-x',
+                './usr/local/lib/python3.5/dist-packages': 'rwxrwsr-x',
+                './usr/sbin/pppd': 'rwsr-xr--',
+                './var/local': 'rwxrwsr-x',
+                './var/mail': 'rwxrwsr-x',
+                './var/spool/cron/crontabs': 'rwx-wx--T',
+                './var/tmp': 'rwxrwxrwt',
+            },
         }
 
+        self.sec_browser_support_overrides = ['screencloudplayer',
+                                              'webdemo']
+
     def _unsquashfs_lls(self, snap_pkg):
         '''Run unsquashfs -lls on a snap package'''
         return cmd(['unsquashfs', '-lls', snap_pkg])
 
-    def check_security_policy_vendor(self):
-        '''Check policy-vendor'''
-        if not self.is_snap2:
-            return
-
-        t = 'info'
-        n = self._get_check_name('policy-vendor')
-        s = 'OK'
-        if self.policy_vendor not in self.aa_policy:
-            t = 'error'
-            s = "unknown policy-vendor '%s'" % self.policy_vendor
-        self._add_result(t, n, s)
-
-    def check_security_policy_version(self):
-        '''Check policy-version'''
-        if not self.is_snap2 or self.policy_vendor not in self.aa_policy:
-            return
-
-        t = 'info'
-        n = self._get_check_name('policy-version')
-        s = 'OK'
-        if self.policy_version not in self.aa_policy[self.policy_vendor]:
-            t = 'error'
-            s = "unknown policy-version '%s'" % self.policy_version
-        self._add_result(t, n, s)
-
-    def _verify_iface(self, name, iface, interface):
-        sec_type = self._get_policy_group_type(self.policy_vendor,
-                                               self.policy_version,
-                                               interface)
-        if sec_type is None:
-            return  # not in aa_policy
-
-        o = self._devmode_override()
-        if name.endswith('slot') and interface not in self.sec_safe_slots:
-            t = 'info'
-            n = self._get_check_name('is_slot', app=iface,
-                                     extra=interface)
-            s = "OK"
-            m = False
-            if 'type' in self.snap_yaml and self.snap_yaml['type'] == 'gadget':
-                s = 'OK (slots in gadget snaps are ok)'
-            else:
-                t = 'warn'
-                s = "(NEEDS REVIEW) slots requires approval"
-                if o is None:
-                    m = True
-            self._add_result(t, n, s, manual_review=m, override_result_type=o)
-
-        t = 'info'
-        n = self._get_check_name('%s_safe' % name, app=iface, extra=interface)
-        s = "OK"
-        m = False
-        l = None
-        if interface == "debug":
-            t = 'error'
-            s = "'%s' not for production use" % interface
-            l = 'http://askubuntu.com/a/562123/94326'
-            if o is None:
-                m = True
-        elif sec_type == "reserved":
-            t = 'error'
-            s = "%s interface '%s' for vetted applications only" % (sec_type,
-                                                                    interface)
-            if o is None:
-                m = True
-        elif sec_type != "common":
-            t = 'error'
-            s = "unknown type '%s' for interface '%s'" % (sec_type, interface)
-            o = None
-        self._add_result(t, n, s, l, manual_review=m, override_result_type=o)
-
-    def check_security_plugs(self):
-        '''Check security plugs'''
-        if not self.is_snap2 or 'plugs' not in self.snap_yaml:
-            return
-
-        for plug in self.snap_yaml['plugs']:
-            # If the 'interface' name is the same as the 'plug' name, then
-            # 'interface' is optional since the interface name and the plug
-            # name are the same
-            interface = plug
-            if 'interface' in self.snap_yaml['plugs'][plug]:
-                interface = self.snap_yaml['plugs'][plug]['interface']
-
-            self._verify_iface('plug', plug, interface)
-
-    def check_security_apps_plugs(self):
-        '''Check security app plugs'''
-        if not self.is_snap2 or 'apps' not in self.snap_yaml:
-            return
-
-        for app in self.snap_yaml['apps']:
-            if 'plugs' not in self.snap_yaml['apps'][app]:
-                continue
-
-            # The interface referenced in the app's 'plugs' field can either be
-            # a known interface (when the interface name reference and the
-            # interface is the same) or can reference a name in the snap's
-            # toplevel 'plugs' mapping
-            for plug_ref in self.snap_yaml['apps'][app]['plugs']:
-                if not isinstance(plug_ref, str):
-                    continue  # checked elsewhere
-                elif plug_ref not in self.interfaces:
-                    continue  # check_security_plugs() verifies these
-
-                self._verify_iface('app_plug', app, plug_ref)
-
     def check_security_plugs_browser_support_with_daemon(self):
         '''Check security plugs - browser-support not used with daemon'''
         def _plugref_is_interface(ref, iface):
@@ -240,48 +173,18 @@ class SnapReviewSecurity(SnapReview):
 
             for plug_ref in plugs:
                 if _plugref_is_interface(plug_ref, "browser-support"):
-                    t = 'warn'
+                    if self.snap_yaml['name'] in \
+                            self.sec_browser_support_overrides:
+                        t = 'info'
+                        s = "OK (allowing 'daemon' with 'browser-support'"
+                    else:
+                        t = 'warn'
+                        s = "(NEEDS REVIEW) 'daemon' should not be used " + \
+                            "with 'browser-support'"
                     n = self._get_check_name('daemon_with_browser-support',
                                              app=app)
-                    s = "(NEEDS REVIEW) 'daemon' should not be used with 'browser-support'"
                     self._add_result(t, n, s, manual_review=True)
 
-    def check_security_slots(self):
-        '''Check security slots'''
-        if not self.is_snap2 or 'slots' not in self.snap_yaml:
-            return
-
-        for slot in self.snap_yaml['slots']:
-            # If the 'interface' name is the same as the 'slot' name, then
-            # 'interface' is optional since the interface name and the slot
-            # name are the same
-            interface = slot
-            if 'interface' in self.snap_yaml['slots'][slot]:
-                interface = self.snap_yaml['slots'][slot]['interface']
-
-            self._verify_iface('slot', slot, interface)
-
-    def check_security_apps_slots(self):
-        '''Check security app slots'''
-        if not self.is_snap2 or 'apps' not in self.snap_yaml:
-            return
-
-        for app in self.snap_yaml['apps']:
-            if 'slots' not in self.snap_yaml['apps'][app]:
-                continue
-
-            # The interface referenced in the app's 'slots' field can either be
-            # a known interface (when the interface name reference and the
-            # interface is the same) or can reference a name in the snap's
-            # toplevel 'slots' mapping
-            for slot_ref in self.snap_yaml['apps'][app]['slots']:
-                if not isinstance(slot_ref, str):
-                    continue  # checked elsewhere
-                elif slot_ref not in self.interfaces:
-                    continue  # check_security_slots() verifies these
-
-                self._verify_iface('app_slot', app, slot_ref)
-
     def check_apparmor_profile_name_length(self):
         '''Check AppArmor profile name length'''
         if not self.is_snap2 or 'apps' not in self.snap_yaml:
@@ -339,8 +242,8 @@ class SnapReviewSecurity(SnapReview):
             t = 'info'
             n = self._get_check_name('squashfs_resquash_1555305')
             s = 'cannot reproduce squashfs'
-            l = 'https://launchpad.net/bugs/1555305'
-            self._add_result(t, n, s, link=l)
+            link = 'https://launchpad.net/bugs/1555305'
+            self._add_result(t, n, s, link=link)
             return
         # end LP: #1555305 workaround
 
@@ -475,7 +378,10 @@ class SnapReviewSecurity(SnapReview):
                                                                    fname))
                 continue
             if ftype == 'd' or ftype == '-':
-                if not _check_allowed_perms(mode, ['r', 'w', 'x', '-']):
+                perms = ['r', 'w', 'x', '-']
+                if ftype == 'd':  # allow sticky directories for stage-packages
+                    perms.append('t')
+                if not _check_allowed_perms(mode, perms):
                     if pkgname not in self.sec_mode_overrides or \
                         fname not in self.sec_mode_overrides[pkgname] or \
                             self.sec_mode_overrides[pkgname][fname] != mode:
