@@ -90,226 +90,6 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
             sum += len(c.click_report[i])
         self.assertTrue(sum == 0)
 
-    def test_check_security_policy_vendor(self):
-        '''Test check_security_policy_vendor()'''
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_policy_vendor()
-        report = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_policy_vendor_missing(self):
-        '''Test check_security_policy_vendor() - missing'''
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy.pop("ubuntu-core", None)
-        c.check_security_policy_vendor()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_policy_version(self):
-        '''Test check_security_policy_vesion()'''
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_policy_version()
-        report = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_policy_version_missing(self):
-        '''Test check_security_policy_vesion()'''
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"].pop("16.04", None)
-        c.check_security_policy_version()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs(self):
-        ''' Test check_security_plugs()'''
-        plugs = self._create_top_plugs()
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_none(self):
-        ''' Test check_security_plugs() - None'''
-        self.set_test_snap_yaml("plugs", None)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_empty(self):
-        ''' Test check_security_plugs() - empty'''
-        self.set_test_snap_yaml("plugs", {})
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_debug(self):
-        ''' Test check_security_plugs() - debug'''
-        plugs = self._create_top_plugs()
-        plugs['debug'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("debug")
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_reserved(self):
-        ''' Test check_security_plugs() - reserved'''
-        plugs = self._create_top_plugs()
-        plugs['rsrved'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_reserved_strict(self):
-        ''' Test check_security_plugs() - reserved (strict)'''
-        plugs = self._create_top_plugs()
-        plugs['rsrved'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        self.set_test_snap_yaml("confinement", "strict")
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_reserved_devmode(self):
-        ''' Test check_security_plugs() - reserved (devmode)'''
-        plugs = self._create_top_plugs()
-        plugs['rsrved'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        self.set_test_snap_yaml("confinement", "devmode")
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 3, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-        expected = dict()
-        expected['error'] = dict()
-        expected['warn'] = dict()
-        expected['info'] = dict()
-        name = 'security-snap-v2:plug_safe:rsrved:rsrved'
-        expected['info'][name] = {"text": "[ERROR] reserved interface "
-                                          "'rsrved' for vetted applications "
-                                          "only",
-                                  "manual_review": False}
-        self.check_results(report, expected=expected)
-
-    def test_check_security_plugs_no_plugs(self):
-        ''' Test check_security_plugs() - no plugs'''
-        self.set_test_snap_yaml("plugs", None)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_unknown_type(self):
-        ''' Test check_security_plugs() - unknown type'''
-        plugs = self._create_top_plugs()
-        plugs['bad-type'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["nonexistent"] = ["bad-type"]
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_plugs_nonexistent(self):
-        ''' Test check_security_plugs() - nonexistent'''
-        plugs = dict()
-        plugs['nonexistent'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_plugs(self):
-        ''' Test check_security_apps_plugs()'''
-        plugs = self._create_top_plugs()
-        apps = self._create_apps_plugs()
-        self.set_test_snap_yaml("plugs", plugs)
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_plugs()
-        report = c.click_report
-        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-        # Note: c.check_security_apps_plugs() only checks plugs that are not
-        # referenced in the toplevel plugs so while self._create_apps_plugs()
-        # has four apps, only two of the apps reference plugs not in the
-        # toplevel plugs.
-        expected = dict()
-        expected['error'] = dict()
-        expected['warn'] = dict()
-        expected['info'] = dict()
-        name = 'security-snap-v2:app_plug_safe:app2:network-bind'
-        expected['info'][name] = {"text": "OK"}
-        name = 'security-snap-v2:app_plug_safe:app3:network-bind'
-        expected['info'][name] = {"text": "OK"}
-        self.check_results(report, expected=expected)
-
-    def test_check_security_apps_plugs_no_apps(self):
-        ''' Test check_security_apps_plugs() - No apps'''
-        self.set_test_snap_yaml("apps", None)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_plugs_none(self):
-        ''' Test check_security_apps_plugs() - app with no plugs'''
-        apps = {'app1': {'plugs': {}}}
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_plugs_bad(self):
-        ''' Test check_security_apps_plugs() - bad'''
-        apps = {'app1': {'plugs': [{}]}}
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_plugs_empty(self):
-        ''' Test check_security_apps_plugs() - empty'''
-        apps = {'app1': {'plugs': []}}
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_plugs()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
     def test_check_security_plugs_browser_support_with_daemon_top_plugs(self):
         ''' Test check_security_plugs() - daemon with toplevel plugs'''
         plugs = {'browser': {'interface': 'browser-support'}}
@@ -414,212 +194,25 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
         expected_counts = {'info': 0, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
-    def test_check_security_slots(self):
-        ''' Test check_security_slots()'''
-        slots = self._create_top_slots()
-        self.set_test_snap_yaml("slots", slots)
+    def test_check_security_plugs_browser_support_daemon_override(self):
+        ''' Test check_security_plugs() - browser-support w/ daemon override'''
+        apps = {'app1': {'plugs': ['browser-support'],
+                         'daemon': 'simple'}}
+        self.set_test_snap_yaml("apps", apps)
         c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
+        c.sec_browser_support_overrides.append(self.test_snap_yaml["name"])
+        c.check_security_plugs_browser_support_with_daemon()
         report = c.click_report
-        # specifying slots currently requires manual review
-        expected_counts = {'info': 2, 'warn': 2, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_gadget(self):
-        ''' Test check_security_slots() - gadget'''
-        slots = self._create_top_slots()
-        self.set_test_snap_yaml("type", "gadget")
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        # specifying slots with gadgets does not require manual review
-        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_mpris(self):
-        ''' Test check_security_slots() - mpris'''
-        slots = dict()
-        slots['mpris'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        # specifying slots currently requires manual review, unless a safe slot
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
-
-    def test_check_security_slots_content(self):
-        ''' Test check_security_slots() - content'''
-        slots = dict()
-        slots['content'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        # specifying slots currently requires manual review, unless a safe slot
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_none(self):
-        ''' Test check_security_slots() - None'''
-        self.set_test_snap_yaml("slots", None)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_empty(self):
-        ''' Test check_security_slots() - empty'''
-        self.set_test_snap_yaml("slots", {})
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_debug(self):
-        ''' Test check_security_slots() - debug'''
-        slots = self._create_top_slots()
-        slots['debug'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("debug")
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': None, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_reserved(self):
-        ''' Test check_security_slots() - reserved'''
-        slots = self._create_top_slots()
-        slots['rsrved'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': None, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_reserved_strict(self):
-        ''' Test check_security_slots() - reserved (strict)'''
-        slots = self._create_top_slots()
-        slots['rsrved'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        self.set_test_snap_yaml("confinement", "strict")
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': 3, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_reserved_devmode(self):
-        ''' Test check_security_plugs() - reserved (devmode)'''
-        slots = self._create_top_slots()
-        slots['rsrved'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        self.set_test_snap_yaml("confinement", "devmode")
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["reserved"].append("rsrved")
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': 6, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
         expected = dict()
         expected['error'] = dict()
         expected['warn'] = dict()
         expected['info'] = dict()
-        name = 'security-snap-v2:slot_safe:rsrved:rsrved'
-        expected['info'][name] = {"text": "[ERROR] reserved interface "
-                                          "'rsrved' for vetted applications "
-                                          "only",
-                                  "manual_review": False}
-        name = 'security-snap-v2:is_slot:rsrved:rsrved'
-        expected['info'][name] = {"text": "[WARN] (NEEDS REVIEW) slots "
-                                          "requires approval",
-                                  "manual_review": False}
+        name = 'security-snap-v2:daemon_with_browser-support:app1'
+        expected['info'][name] = {"text": "OK (allowing 'daemon' with 'browser-support'"}
         self.check_results(report, expected=expected)
 
-    def test_check_security_slots_unknown_type(self):
-        ''' Test check_security_slots() - unknown type'''
-        slots = self._create_top_slots()
-        slots['bad-type'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.aa_policy["ubuntu-core"]["16.04"]["policy_groups"]["nonexistent"] = ["bad-type"]
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': None, 'warn': None, 'error': 1}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_slots_nonexistent(self):
-        ''' Test check_security_slots() - nonexistent'''
-        slots = dict()
-        slots['nonexistent'] = {}
-        self.set_test_snap_yaml("slots", slots)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_slots(self):
-        ''' Test check_security_apps_slots()'''
-        slots = self._create_top_slots()
-        apps = self._create_apps_slots()
-        self.set_test_snap_yaml("slots", slots)
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_slots()
-        report = c.click_report
-        expected_counts = {'info': 1, 'warn': 1, 'error': 0}
-        self.check_results(report, expected_counts)
-
-        # Note: c.check_security_apps_slots() only checks slots that are not
-        # referenced in the toplevel slots so while self._create_apps_slots()
-        # has two apps, only one of the apps reference slots not in the
-        # toplevel slots.
-        expected = dict()
-        expected['error'] = dict()
-        expected['warn'] = dict()
-        expected['info'] = dict()
-        name = 'security-snap-v2:app_slot_safe:app2:network-bind'
-        expected['info'][name] = {"text": "OK"}
-        self.check_results(report, expected=expected)
-
-    def test_check_security_apps_slots_none(self):
-        ''' Test check_security_apps_slots() - None'''
-        self.set_test_snap_yaml("apps", None)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_slots_bad(self):
-        ''' Test check_security_apps_slots() - bad'''
-        apps = {'app1': {'slots': [{}]}}
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
-    def test_check_security_apps_slots_empty(self):
-        ''' Test check_security_apps_slots() - empty'''
-        apps = {'app1': {'slots': []}}
-        self.set_test_snap_yaml("apps", apps)
-        c = SnapReviewSecurity(self.test_name)
-        c.check_security_apps_slots()
-        report = c.click_report
-        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
-        self.check_results(report, expected_counts)
-
     def test_check_apparmor_profile_name_length(self):
         '''Test check_apparmor_profile_name_length()'''
         apps = {'app1': {'plugs': ['iface-caps']}}
@@ -841,12 +434,41 @@ short
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
-    def test_check_squashfs_files_bad_mode_sticky(self):
-        '''Test check_squashfs_files() - bad mode - sticky dir'''
+    def test_check_squashfs_files_mode_openwrt_tmp(self):
+        '''Test check_squashfs_files() - mode - openwrt /tmp'''
+        out = '''Parallel unsquashfs: Using 4 processors
+8 inodes (8 blocks) to write
+
+-rwxrwxrwt root/root             14528 2016-08-02 18:18 squashfs-root/rootfs/tmp
+'''
+        self.set_test_unsquashfs_lls(out)
+        self.set_test_snap_yaml("name", "openwrt")
+        c = SnapReviewSecurity(self.test_name)
+        c.check_squashfs_files()
+        report = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_squashfs_files_mode_sticky_dir(self):
+        '''Test check_squashfs_files() - mode - sticky dir'''
         out = '''Parallel unsquashfs: Using 4 processors
 8 inodes (8 blocks) to write
 
 drwxrwxrwt root/root                38 2016-03-11 12:25 squashfs-root/foo
+'''
+        self.set_test_unsquashfs_lls(out)
+        c = SnapReviewSecurity(self.test_name)
+        c.check_squashfs_files()
+        report = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_squashfs_files_bad_mode_sticky_file(self):
+        '''Test check_squashfs_files() - bad mode - sticky file'''
+        out = '''Parallel unsquashfs: Using 4 processors
+8 inodes (8 blocks) to write
+
+-rwxrwxrwt root/root                38 2016-03-11 12:25 squashfs-root/foo
 '''
         self.set_test_unsquashfs_lls(out)
         c = SnapReviewSecurity(self.test_name)
